@@ -240,14 +240,9 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
         dom.appendChild(self.get_emisor())
         dom.appendChild(self.get_receptor())
 
-        if self.tipo_objeto == EGRESO:
-            dom.appendChild(self.get_cfdi_relacionados())
-        if self.tipo_objeto == INGRESO and self.complemento == COMPLEMENTO_CARTA_PORTE and self.data.get('tipo_relacion') == '05':
-            # Agregar lo siguiente
-            # 1.- Información en el campo TipoEstación de la sección Ubicación con el valor “02” (Intermedia), contenida en el catálogo del complemento Carta Porte, c_TipoEstacion, publicado en el portal del SAT.
-            # 2.- Información en la sección TransporteFerroviario de la sección Mercancias.
-            dom.appendChild(self.get_cfdi_relacionados())
-        elif len(self.data.get('cfdi_relacionados', [])) > 0:
+        if len(self.data.get('cfdi_relacionados', [])) > 0:
+            if self.data.get('tipo_relacion', '') == '':
+                raise Exception('Debe especificar el tipo de relación de los documentos')
             dom.appendChild(self.get_cfdi_relacionados())
 
         if (self.tipo_objeto == INGRESO) or (self.tipo_objeto == EGRESO and not self.global_data.get('concepto_fijo')):
@@ -303,12 +298,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
     def get_cfdi_relacionados(self):
         try:
             relacionados = self.dom.createElement('cfdi:CfdiRelacionados')
-            if self.tipo_objeto == INGRESO:
-                relacionados.setAttribute('TipoRelacion', self.data.get('tipo_relacion'))
-            elif self.tipo_objeto == PAGO:
-                relacionados.setAttribute('TipoRelacion','04')  # Sustitución de CFDI previos
-            elif self.tipo_objeto == EGRESO:
-                relacionados.setAttribute('TipoRelacion', self.data.get('tipo_relacion'))
+            relacionados.setAttribute('TipoRelacion', self.data.get('tipo_relacion'))
             cfdirelacionados = self.data.get('cfdi_relacionados')
             for uuid_cfdi in cfdirelacionados:
                 relacionado = self.dom.createElement('cfdi:CfdiRelacionado')
